==> wxGTK-2.8.10.1-x86_64-4ab.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libwx_baseu-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_baseu-2.8.so.0.6.0 libwx_baseu-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu-2.8.so )
( cd usr/lib64 ; ln -sf libwx_baseu-2.8.so.0 libwx_baseu-2.8.so )
( cd usr/lib64 ; rm -rf libwx_baseu_net-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_baseu_net-2.8.so.0.6.0 libwx_baseu_net-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu_net-2.8.so )
( cd usr/lib64 ; ln -sf libwx_baseu_net-2.8.so.0 libwx_baseu_net-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_core-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_core-2.8.so.0.6.0 libwx_gtk2u_core-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_core-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_core-2.8.so.0 libwx_gtk2u_core-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_adv-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_adv-2.8.so.0.6.0 libwx_gtk2u_adv-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_adv-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_adv-2.8.so.0 libwx_gtk2u_adv-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_media-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_media-2.8.so.0.6.0 libwx_gtk2u_media-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_media-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_media-2.8.so.0 libwx_gtk2u_media-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_html-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_html-2.8.so.0.6.0 libwx_gtk2u_html-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_html-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_html-2.8.so.0 libwx_gtk2u_html-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_qa-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_qa-2.8.so.0.6.0 libwx_gtk2u_qa-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_qa-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_qa-2.8.so.0 libwx_gtk2u_qa-2.8.so )
( cd usr/lib64 ; rm -rf libwx_baseu_xml-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_baseu_xml-2.8.so.0.6.0 libwx_baseu_xml-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu_xml-2.8.so )
( cd usr/lib64 ; ln -sf libwx_baseu_xml-2.8.so.0 libwx_baseu_xml-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_xrc-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_xrc-2.8.so.0.6.0 libwx_gtk2u_xrc-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_xrc-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_xrc-2.8.so.0 libwx_gtk2u_xrc-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_aui-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_aui-2.8.so.0.6.0 libwx_gtk2u_aui-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_aui-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_aui-2.8.so.0 libwx_gtk2u_aui-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_richtext-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_richtext-2.8.so.0.6.0 libwx_gtk2u_richtext-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_richtext-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_richtext-2.8.so.0 libwx_gtk2u_richtext-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gl-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gl-2.8.so.0.6.0 libwx_gtk2u_gl-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gl-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gl-2.8.so.0 libwx_gtk2u_gl-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_fl-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_fl-2.8.so.0.6.0 libwx_gtk2u_fl-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_fl-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_fl-2.8.so.0 libwx_gtk2u_fl-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos-2.8.so.0.6.0 libwx_gtk2u_gizmos-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos-2.8.so.0 libwx_gtk2u_gizmos-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos_xrc-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos_xrc-2.8.so.0.6.0 libwx_gtk2u_gizmos_xrc-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos_xrc-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos_xrc-2.8.so.0 libwx_gtk2u_gizmos_xrc-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_ogl-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_ogl-2.8.so.0.6.0 libwx_gtk2u_ogl-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_ogl-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_ogl-2.8.so.0 libwx_gtk2u_ogl-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_plot-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_plot-2.8.so.0.6.0 libwx_gtk2u_plot-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_plot-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_plot-2.8.so.0 libwx_gtk2u_plot-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_stc-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_stc-2.8.so.0.6.0 libwx_gtk2u_stc-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_stc-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_stc-2.8.so.0 libwx_gtk2u_stc-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_svg-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_svg-2.8.so.0.6.0 libwx_gtk2u_svg-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_svg-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_svg-2.8.so.0 libwx_gtk2u_svg-2.8.so )
( cd usr/bin ; rm -rf wxrc )
( cd usr/bin ; ln -sf wxrc-2.8 wxrc )
( cd usr/bin ; rm -rf wx-config )
( cd usr/bin ; ln -sf /usr/lib64/wx/config/gtk2-unicode-release-2.8 wx-config )

==> wxGTK-2.8.12.1-x86_64-1ab.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf wxrc )
( cd usr/bin ; ln -sf wxrc-2.8 wxrc )
( cd usr/bin ; rm -rf wx-config )
( cd usr/bin ; ln -sf /usr/lib64/wx/config/gtk2-unicode-release-2.8 wx-config )
( cd usr/lib64 ; rm -rf libwx_gtk2u_aui-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_aui-2.8.so.0.8.0 libwx_gtk2u_aui-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_aui-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_aui-2.8.so.0 libwx_gtk2u_aui-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_html-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_html-2.8.so.0.8.0 libwx_gtk2u_html-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_richtext-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_richtext-2.8.so.0.8.0 libwx_gtk2u_richtext-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_xrc-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_xrc-2.8.so.0.8.0 libwx_gtk2u_xrc-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_baseu-2.8.so.0.8.0 libwx_baseu-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_adv-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_adv-2.8.so.0.8.0 libwx_gtk2u_adv-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu-2.8.so )
( cd usr/lib64 ; ln -sf libwx_baseu-2.8.so.0 libwx_baseu-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_media-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_media-2.8.so.0.8.0 libwx_gtk2u_media-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu_net-2.8.so )
( cd usr/lib64 ; ln -sf libwx_baseu_net-2.8.so.0 libwx_baseu_net-2.8.so )
( cd usr/lib64 ; rm -rf libwx_baseu_xml-2.8.so )
( cd usr/lib64 ; ln -sf libwx_baseu_xml-2.8.so.0 libwx_baseu_xml-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos-2.8.so.0 libwx_gtk2u_gizmos-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_ogl-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_ogl-2.8.so.0 libwx_gtk2u_ogl-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_plot-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_plot-2.8.so.0.8.0 libwx_gtk2u_plot-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_ogl-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_ogl-2.8.so.0.8.0 libwx_gtk2u_ogl-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_qa-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_qa-2.8.so.0 libwx_gtk2u_qa-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_core-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_core-2.8.so.0 libwx_gtk2u_core-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_svg-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_svg-2.8.so.0.8.0 libwx_gtk2u_svg-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos-2.8.so.0.8.0 libwx_gtk2u_gizmos-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_html-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_html-2.8.so.0 libwx_gtk2u_html-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos_xrc-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos_xrc-2.8.so.0 libwx_gtk2u_gizmos_xrc-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_xrc-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_xrc-2.8.so.0 libwx_gtk2u_xrc-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gizmos_xrc-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gizmos_xrc-2.8.so.0.8.0 libwx_gtk2u_gizmos_xrc-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_media-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_media-2.8.so.0 libwx_gtk2u_media-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_stc-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_stc-2.8.so.0 libwx_gtk2u_stc-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_richtext-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_richtext-2.8.so.0 libwx_gtk2u_richtext-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_mmedia-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_mmedia-2.8.so.0 libwx_gtk2u_mmedia-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_mmedia-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_mmedia-2.8.so.0.8.0 libwx_gtk2u_mmedia-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_fl-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_fl-2.8.so.0 libwx_gtk2u_fl-2.8.so )
( cd usr/lib64 ; rm -rf libwx_baseu_net-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_baseu_net-2.8.so.0.8.0 libwx_baseu_net-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_baseu_xml-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_baseu_xml-2.8.so.0.8.0 libwx_baseu_xml-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_stc-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_stc-2.8.so.0.8.0 libwx_gtk2u_stc-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_fl-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_fl-2.8.so.0.8.0 libwx_gtk2u_fl-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gl-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gl-2.8.so.0.8.0 libwx_gtk2u_gl-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_qa-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_qa-2.8.so.0.8.0 libwx_gtk2u_qa-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_svg-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_svg-2.8.so.0 libwx_gtk2u_svg-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_adv-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_adv-2.8.so.0 libwx_gtk2u_adv-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_gl-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_gl-2.8.so.0 libwx_gtk2u_gl-2.8.so )
( cd usr/lib64 ; rm -rf libwx_gtk2u_core-2.8.so.0 )
( cd usr/lib64 ; ln -sf libwx_gtk2u_core-2.8.so.0.8.0 libwx_gtk2u_core-2.8.so.0 )
( cd usr/lib64 ; rm -rf libwx_gtk2u_plot-2.8.so )
( cd usr/lib64 ; ln -sf libwx_gtk2u_plot-2.8.so.0 libwx_gtk2u_plot-2.8.so )
